==> cyphesis-cpp_0.6.0.orig.tar.xz: cyphesis-0.6.0/tests/AreaPropertytest.cpp <==
// Cyphesis Online RPG Server and AI Engine
// Copyright (C) 2009 Alistair Riddoch
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software Foundation,
// Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA

// $Id: 58aa8125ee9c39d6d15b2d85bd28a157b6150b79 $

#ifdef NDEBUG
#undef NDEBUG
#endif
#ifndef DEBUG
#define DEBUG
#endif

#include "PropertyCoverage.h"

#include "rulesets/AreaProperty.h"

using Atlas::Message::ListType;
using Atlas::Message::MapType;

int main()
{
    AreaProperty * ap = new AreaProperty();

    PropertyCoverage pc(ap);

    MapType area;
    area["points"] = ListType(1, ListType(3, 1.f));
    area["type"] = "foo";

    pc.testDataAppend(area);

    area["type"] = "polygon";
    pc.testDataAppend(area);

    // Coverage is complete, but it wouldn't hurt to add some bad data here.

    pc.basicCoverage();

    // The is no code in operations.cpp to execute, but we need coverage.
    return 0;
}

// stubs

#include "TestWorld.h"

void TestWorld::message(const Operation & op, Entity & ent)
{
}

Entity * TestWorld::addNewEntity(const std::string &,
                                 const Atlas::Objects::Entity::RootEntity &)
{
    return 0;
}

#include "physics/Shape.h"

const TerrainProperty * TerrainEffectorProperty::getTerrain(Entity * owner)
{
    return 0;
}

Shape * Shape::newFromAtlas(const MapType & data)
{
    return 0;
}

==> cyphesis-cpp_0.6.2.orig.tar.xz: cyphesis-0.6.2/tests/AreaPropertytest.cpp <==
// Cyphesis Online RPG Server and AI Engine
// Copyright (C) 2009 Alistair Riddoch
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software Foundation,
// Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA


#ifdef NDEBUG
#undef NDEBUG
#endif
#ifndef DEBUG
#define DEBUG
#endif

#include "PropertyCoverage.h"

#include "rulesets/AreaProperty.h"

using Atlas::Message::ListType;
using Atlas::Message::MapType;

int main()
{
    AreaProperty * ap = new AreaProperty();

    PropertyChecker<AreaProperty> pc(ap);

    MapType area;
    area["points"] = ListType(1, ListType(3, 1.f));
    area["type"] = "foo";

    pc.testDataAppend(area);

    area["type"] = "polygon";
    pc.testDataAppend(area);

    // Coverage is complete, but it wouldn't hurt to add some bad data here.

    pc.basicCoverage();

    // The is no code in operations.cpp to execute, but we need coverage.
    return 0;
}

// stubs

#include "TestWorld.h"

void TestWorld::message(const Operation & op, LocatedEntity & ent)
{
}

LocatedEntity * TestWorld::addNewEntity(const std::string &,
                                 const Atlas::Objects::Entity::RootEntity &)
{
    return 0;
}

#include "physics/Shape.h"

const TerrainProperty * TerrainEffectorProperty::getTerrain(LocatedEntity * owner)
{
    return 0;
}

Shape * Shape::newFromAtlas(const MapType & data)
{
    return 0;
}
